{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template theme_classic/footer

    Page footer.

    Example context (json):
    {
        "output": {
            "course_footer": "More information about this course",
            "page_doc_link": "<a href='https://docs.moodle.org/'>Documentation for this page</a>",
            "login_info": "You are logged in as cute kitten",
            "supportemail": "<a href=\"#\">Contact site support</a>",
            "services_support_link": "Services and support"
        }
    }
}}
<footer id="page-footer" class="footer-dark bg-dark text-light">
    <div class="container footer-dark-inner">
        <div id="course-footer">{{{ output.course_footer }}}</div>
        {{#output.has_communication_links}}
            <button onclick="window.open('{{output.communication_url}}', '_blank', 'noreferrer')" class="btn btn-icon rounded-circle bg-primary text-white btn-footer-communication" aria-label="{{#str}}communicationroomlink, course{{/str}}">
                {{#pix}}t/messages-o, core{{/pix}}
            </button>
        {{/output.has_communication_links}}
        <div class="pb-3">
            {{#output.has_communication_links}}
                <div class="footer-section footer-link-communication">
                    <div class="footer-support-link">{{{ output.communication_link }}}</div>
                </div>
            {{/output.has_communication_links}}
            {{# output.page_doc_link }}
                <div class="footer-support-link">{{{ output.page_doc_link }}}</div>
            {{/ output.page_doc_link }}
            {{# output.services_support_link }}
                <div class="footer-support-link">{{{ output.services_support_link }}}</div>
            {{/ output.services_support_link }}
            {{# output.supportemail }}
                <div class="footer-support-link">{{{ output.supportemail }}}</div>
            {{/ output.supportemail }}
        </div>

        {{{ output.login_info }}}
        <div class="tool_usertours-resettourcontainer"></div>
        {{{ output.home_link }}}
        <nav class="nav navbar-nav d-md-none" aria-label="{{#str}}custommenu, admin{{/str}}">
            {{# output.custom_menu_flat }}
                <ul class="list-unstyled pt-3">
                    {{> theme_boost/custom_menu_footer }}
                </ul>
            {{/ output.custom_menu_flat }}
        </nav>
        {{{ output.standard_footer_html }}}
        {{{ output.debug_footer_html }}}
        {{{ output.standard_end_of_body_html }}}
    </div>
</footer>
