$nabvar-bg-color: $dark !default;

.navbar-bootswatch {
    @extend .navbar-dark;
    background-color: $nabvar-bg-color;

    .usermenu {
        color: $navbar-dark-color;
        .login a {
            color: $navbar-dark-color;
        }
    }
    a.dropdown-toggle,
    a .usertext {
        color: $navbar-dark-active-color;
        &:hover,
        &:focus {
            color: $navbar-dark-hover-color;
        }

        &.disabled {
            color: $navbar-dark-disabled-color;
        }
    }
    .dropdown-menu a .icon {
        color: inherit !important; // stylelint-disable-line declaration-no-important
    }
}
